# Stor Blockchain

Stor is a community-driven green cryptocurrency based on a proof of space and time consensus algorithm.

For more information, see our website at https://stor.network

# License

SPDX-License-Identifier: Apache-2.0

Copyright 2021 Stor Network

Copyright 2021 Chia Network

# Note

Stor is not affiliated with Chia Network, Inc. Chia™ may be a trademark or registered trademark of Chia Network, Inc., and is used only as nominative reference to the open-source protocols and software developed and released by Chia Network, Inc.